#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52.1
visibility:           public
id:                   hledger-web-1.52.1-I8kzIGs8hmi5wGthaoo98j
key:                  hledger-web-1.52.1-I8kzIGs8hmi5wGthaoo98j
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  8c8c72f3b74032e3715a437fbfca8f37
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52.1-I8kzIGs8hmi5wGthaoo98j
depends:
    Decimal-0.5.2-89pPFenfxXhDikm7hTtAWf
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1
    base64-1.0-LFiJQK36UIBkGhICy051P
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7
    blaze-markup-0.8.3.0-8LKEXVAssOfaSB46gmUNg bytestring-0.11.5.3
    case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    clientsession-0.9.3.0-GzH6d1hf6rqXbDwEqannU
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-KPHDCDDIHN1EOURpcrFXUe
    conduit-extra-1.3.8-1lTAw5MbR9d8jW8YQMIELA containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-J2nH1si97LP2pkcRW1gnIU
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.7.0-Gzf3QnhC8Vu2bLBSBbLufk
    hjsmin-0.2.1-FewwBQL5OBm6KgKivCsOep
    hledger-1.52.1-37Le6TcQnoEHa1ESovDFuM
    hledger-lib-1.52.1-3cw181avHZw5JGimckRCzR
    hspec-2.11.7-FxYk9RksUQ4Ah0F04Y4GJN
    http-client-0.7.19-uRvF7eEYhRDNuWEwLS8eA
    http-conduit-2.3.9.1-3jVRXfysx7LHah4LOBTB7z
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    megaparsec-9.7.1-4UEkY3VkDbeLSqlGrcJOet mtl-2.3.1
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe
    shakespeare-2.1.7.1-4GEtO0QMMUbDgIC6Gmwynm
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-7Q1StMrvuG9I60m4DIlvtT
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-cors-0.2.7-BYhZU0mGlnUBrWwCBBIomK
    wai-extra-3.1.18-HZccfn8lStF2qIDmQsBXmA
    wai-handler-launch-3.0.3.1-9glfokXqViaLKsryiGtc71
    warp-3.4.0-KIEmCyfVmmO5GM68R2rzXC
    yaml-0.11.11.2-Gz9Bz4lbRgP2FR94qGDleq
    yesod-1.6.2.3-B21Pp8BbFZt7ECl1K1xSii
    yesod-core-1.6.28.0-AezvvnuH0ml37P736wuQLI
    yesod-form-1.7.9.3-8zYEQ3uPbVB9vHmSyxLRd7
    yesod-static-1.6.1.2-L69qe620mPMC831kVk4ZgX
    yesod-test-1.7.0.1-FubSnUYWVxKFULTsNjDU9l

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

